.. image:: https://travis-ci.com/FrancoLM/slayer.svg?branch=master
    :target: https://travis-ci.com/FrancoLM/slayer
.. image:: https://readthedocs.org/projects/slayer/badge/?version=latest
    :target: http://slayer.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

Slayer is the QA Automation Framework that came to SLAY!
--------------------------------------------------------

Slayer is a QA Automation Framework developed in Python, based on BDD.

BDD, or Behavior Driven Development, is a software development process emerged from Test Driven Development (TDD).

Besides following the practices of TDD, BDD provides an easy-to-understand vocabulary for developers and stakeholders.
Having a common vocabulary helps both technical and non-technical members in an organization to better communicate and to create software with higher quality.

This framework uses a lot of the functionality provided by the `Python Behave project <http://behave.readthedocs.io/en/latest/>`_.

Please go to the `Documentation <http://slayer.readthedocs.io/en/latest/?>`_ for information on how to install, run and modify Slayer!